#!/bin/bash
# Preparing simulation file
SELF_DIR="$( cd "$( dirname "$0" )" && pwd )"

function exit_cleanup {
    rm $SELF_DIR/../sim.pid
    exit
}

$SELF_DIR/cleanup
rm -f tmp.csv

echo "Analog simulation started." 1>>$SELF_DIR/../sim.stdout 2>>$SELF_DIR/../sim.stderr
echo "Initializing solver. This may take a minute..." 1>>$SELF_DIR/../sim.stdout 2>>$SELF_DIR/../sim.stderr

echo $$ > $SELF_DIR/../sim.pid


if [ "$7" = "0" ]; then		# piezo mode
cp $SELF_DIR/param.empty $SELF_DIR/param.par
sed -i 's/par1/'$1'/g' $SELF_DIR/param.par
sed -i 's/par2/'$2'/g' $SELF_DIR/param.par
sed -i 's/par3/'$3'/g' $SELF_DIR/param.par
sed -i 's/par4/"NaN"/g' $SELF_DIR/param.par
sed -i 's/par5/'$5'/g' $SELF_DIR/param.par
sed -i 's/par6/'$6'/g' $SELF_DIR/param.par
echo PIEZ

#run ELDO
#$SELF_DIR/run_eldo.sh $SELF_DIR/top_piez.cir > /dev/null
$SELF_DIR/run_eldo.sh $SELF_DIR/top_piez.cir > $SELF_DIR/eldo.log

    if [ $? -ne 0 ]; then
	echo "ERROR: ELDO finished unexpectedly. See 'eldo.log' for details." >>$SELF_DIR/../sim.stderr 2>&1
	exit_cleanup
    fi

elif [ "$7" = "1" ]; then	#capacitive mode
cp $SELF_DIR/param.empty $SELF_DIR/param.par
sed -i 's/par1/'$1'/g' $SELF_DIR/param.par
sed -i 's/par2/'$2'/g' $SELF_DIR/param.par
sed -i 's/par3/"NaN"/g' $SELF_DIR/param.par
sed -i 's/par4/'$4'/g' $SELF_DIR/param.par
sed -i 's/par5/"NaN"/g' $SELF_DIR/param.par
sed -i 's/par6/"NaN"/g' $SELF_DIR/param.par
echo CAPAC

#run ELDO
$SELF_DIR/run_eldo.sh $SELF_DIR/top_capac.cir > $SELF_DIR/eldo.log

    if [ $? -ne 0 ]; then
	echo "ERROR: ELDO finished unexpectedly. See 'eldo.log' for details." >>$SELF_DIR/../sim.stderr 2>&1
	exit_cleanup
    fi

fi

echo "Post-processing simulation output...please wait." 1>>$SELF_DIR/../sim.stdout 2>>$SELF_DIR/../sim.stderr
tail -n+2 results/analog_output.csv | sed "s/\t/ /g" > tmp.csv
mv tmp.csv results/analog_output.csv

echo "Simulation progress" >> $SELF_DIR/eldo.log

rm -f $SELF_DIR/../sim.pid $SELF_DIR/*.id

echo "Analog simulation finished." 1>>$SELF_DIR/../sim.stdout 2>>$SELF_DIR/../sim.stderr
