#!/bin/sh
SELF_DIR="$( cd "$( dirname "$0" )" && pwd )"
$SELF_DIR/cleanup

echo "Digital simulation started." 1>$SELF_DIR/../sim.stdout 2>$SELF_DIR/../sim.stderr

echo $$ > $SELF_DIR/../sim.pid

if [ $# -ne 8 ]; then
	echo "Usage: $0 <measurement window> <comm protocol> <bytes per frame> <UART bps> <UART stop bits> <SPI clock polarity> <SPI clock phase>" >$SELF_DIR/../sim.stderr 2>&1
	exit -1
fi


export LM_LICENSE_FILE=1717@cad:5280@cad

export MGC_AMS_HOME=/soft/mentor/ams
export anacad=$MGC_AMS_HOME
export AMS_VCO_MODE=64

export LANG=default
export MGC_HTML_BROWSER=/usr/bin/firefox
export MGC_HTML_OLH_DIR=$MGC_HOME/docs/htmldocs
export MGC_PDF_OLH=$MGC_HOME/docs/pdfdocs
export PATH=$MGC_HOME/bin:$MGC_AMS_HOME/bin:$MGC_AMS_HOME/modeltech/bin:$PATH

PARAM=$SELF_DIR/parameters.conf

SIM_TIME=$1
measure_window=`echo $2 | awk '{printf "%e",$1}'`
comm_protocol=$3
bytes_per_frame=$4
UART_bps=$5
UART_stop_bits=$6
SPI_CPOL=$7
SPI_CPHA=$8

echo $measure_window > $PARAM
echo $comm_protocol >> $PARAM
echo $bytes_per_frame >> $PARAM
echo $UART_bps >> $PARAM
echo $UART_stop_bits >> $PARAM
echo $SPI_CPOL >> $PARAM
echo $SPI_CPHA >> $PARAM

vsim -gui -do "do ./digit/sim.do; run $SIM_TIME sec"

cat $SELF_DIR/plotheader.txt $SELF_DIR/digit_output_without_header.csv > $SELF_DIR/../results/digital_output.csv

echo "Digital simulation finished." 1>$SELF_DIR/../sim.stdout 2>$SELF_DIR/../sim.stderr

